@@ -65,6 +65,41 @@ int main(int, char *argv[])
     if (R[0][0].as<int>() != int(R[0][0].as<unsigned int>()))
       throw runtime_error("Are there really that many rows in " + Table + "?");
 
+    int i;
+    from_string(R[0][0].c_str(), i);
+    if (i != R[0][0].as<int>())
+      throw runtime_error("from_string() yielded " + to_string(i) + " "
+	  "for '" + R[0][0].c_str() + "'");
+    from_string(string(R[0][0].c_str()), i);
+    if (i != R[0][0].as<int>())
+      throw runtime_error("from_string(const char[],int &) "
+	  "inconsistent with from_string(const std::string &,int &)");
+
+    unsigned int ui;
+    from_string(R[0][0].c_str(), ui);
+    if (int(ui) != i)
+      throw runtime_error("from_string() yields different unsigned int");
+
+    long l;
+    from_string(R[0][0].c_str(), l);
+    if (i != l)
+      throw runtime_error("from_string() yields int that differs from long");
+
+    unsigned long ul;
+    from_string(R[0][0].c_str(), ul);
+    if (ui != l)
+      throw runtime_error("from_string() yields different unsigned long");
+
+    short s;
+    from_string(R[0][0].c_str(), s);
+    if (s != i)
+      throw runtime_error("from_string() yields different short");
+
+    unsigned short us;
+    from_string(R[0][0].c_str(), us);
+    if (us != ui)
+      throw runtime_error("from_string() yields different unsigned short");
+
     // Create an SQL cursor and, for good measure, muddle up its state a bit.
     const string CurName = "MYCUR";
     T.Exec("DECLARE " + CurName + " CURSOR FOR SELECT * FROM " + Table);
@@ -86,8 +121,8 @@ int main(int, char *argv[])
     Cur >> R;
 
     if (R.size() > GetRows)
-      throw logic_error("Expected " + ToString(GetRows) + " rows, "
-		        "got " + ToString(R.size()));
+      throw logic_error("Expected " + to_string(GetRows) + " rows, "
+		        "got " + to_string(R.size()));
 
     if (R.size() < GetRows)
       cerr << "Warning: asked for " << GetRows << " rows, "
@@ -100,14 +135,14 @@ int main(int, char *argv[])
     // Now add one more
     R = Cur.Fetch(1);
     if (R.size() != 1)
-      throw logic_error("Asked for 1 row, got " + ToString(R.size()));
+      throw logic_error("Asked for 1 row, got " + to_string(R.size()));
     AddResult(FirstRows1, R);
 
     // Now see if that Fetch() didn't confuse our cursor's stride
     Cur >> R;
     if (R.size() != GetRows)
-      throw logic_error("Asked for " + ToString(GetRows) + " rows, "
-		        "got " + ToString(R.size()) + ". "
+      throw logic_error("Asked for " + to_string(GetRows) + " rows, "
+		        "got " + to_string(R.size()) + ". "
 			"Looks like Fetch() changed our cursor's stride!");
     AddResult(FirstRows1, R);
 
@@ -130,8 +165,8 @@ int main(int, char *argv[])
     DumpRows(FirstRows2);
 
     if (vector<string>::size_type(R.size()) != FirstRows1.size())
-      throw logic_error("I read " + ToString(FirstRows1.size()) + " rows, "
-		        "but I see " + ToString(R.size()) + " rows "
+      throw logic_error("I read " + to_string(FirstRows1.size()) + " rows, "
+		        "but I see " + to_string(R.size()) + " rows "
 			"when trying to read them backwards!");
 
     sort(FirstRows1.begin(), FirstRows1.end());
@@ -142,7 +177,7 @@ int main(int, char *argv[])
 
     R = Cur.Fetch(Cursor::NEXT());
     if (R.size() != 1) 
-      throw logic_error("NEXT: wanted 1 row, got " + ToString(R.size()));
+      throw logic_error("NEXT: wanted 1 row, got " + to_string(R.size()));
     const string Row = R[0][0].c_str();
 
     Cur += 3;
@@ -150,7 +185,7 @@ int main(int, char *argv[])
 
     R = Cur.Fetch(Cursor::PRIOR());
     if (R.size() != 1)
-      throw logic_error("PRIOR: wanted 1 row, got " + ToString(R.size()));
+      throw logic_error("PRIOR: wanted 1 row, got " + to_string(R.size()));
 
     if (R[0][0].c_str() != Row)
       throw logic_error("First row was '" + Row + "' going forward, "
